import{b as s}from"./index-DICPTgNa.js";import{c as o}from"./vue-i18n.runtime-BTnF4KD_.js";const a={failed:"Action failed",success:"Action was successful",title:"GreaterWMS Open Source Warehouse Management System",description:"GreaterWMS Open Source Warehouse Management System",keywords:"greaterwms, 聚商汇wms,wms-system,open source wms system,开源wms,开源仓库管理软件,warehouse management system, free wms",gohome:"Go Home",cancel:"Cancel",submit:"Submit",login:"Login",register:"Register",passworderror:"Password Is Not The Same",logout:"Logout",logoutnotice:"Welcome Back Again",username:"User Name",password:"Enter Password",password1:"Enter Password",password2:"Enter Password Again",usererror:"User Name Or Password Cannot Be Empty",nodata:"No more data",total:"Total: ",page:"page",per_page:"Per page lines",refresh:"Refresh",refreshdata:"Refresh Data",new:"new",newUser:"New one user",changepassword:"Change Password",changePWD:"What is your new password? (Minimum 3 characters)",sucesschangepwd:"Success change password",permission:"Permission",isactive:"Active",isnotactive:"Not Active",deleteuser:"Delete User",email:"E-Mail",date_joined:"Date Joined",last_login:"Last Login",created_time:"Created Time",updated_time:"Updated Time",action:"Action",confirmnotice:"Delete data can not revert, please confirm you want to delete it!!!",menuTab:{home:"Home"},menuLink:{home:"Home",user:"User List"},upload:{center:"Upload Center",clear:"Clear All",remove:"Remove Uploaded Files",choose:"Choose your files and upload to server",add:"Add files",server:"Upload to server",abort:"Abort upload",delete:"Delete this file",status:"Status: ",idle:"Idle",failed:"Failed"},400:"Bad request (400)",401:"Authorization not obtained (401)",403:"Access denied (403)",404:"Resource does not exist (404)",405:"The function is disabled (405)",408:"Request timed out (408)",409:"Data conflict (409)",410:"Data has been deleted (410)",500:"Server error (500)",501:"Service not implemented (501)",502:"Network error (502)",503:"Service unavailable (503)",504:"Network timeout (504)",505:"HTTP version is not supported (505)"},t={failed:"失败",success:"成功",title:"Bomiot",description:"GreaterWMS开源仓库管理系统",keywords:"greaterwms, 聚商汇wms,wms-system,open source wms system,开源wms,开源仓库管理软件,warehouse management system, free wms",gohome:"回到首页",cancel:"取消",submit:"提交",login:"登入",register:"注册",passworderror:"两次输入的密码不一样",logout:"退出",logoutnotice:"欢迎再来",username:"用户名",password:"输入密码",password1:"输入密码",password2:"再次输入密码",usererror:"用户名或密码不能为空",nodata:"没有请求到任何数据",total:"总共：",page:"页",per_page:"每页多少行",refresh:"刷新",new:"新增",refreshdata:"刷新数据",newUser:"新增用户",changepassword:"修改密码",changePWD:"请输入你的新密码，最少3位",sucesschangepwd:"修改密码成功",permission:"权限控制",isactive:"未锁",isnotactive:"锁定",deleteuser:"删除用户",email:"E-Mail",date_joined:"创建时间",last_login:"最后登入时间",created_time:"创建时间",updated_time:"更新时间",action:"操作",confirmnotice:"删除数据不可逆，请确认操作！！！",menuTab:{home:"首页"},menuLink:{home:"首页",user:"用户列表"},upload:{center:"上传中心",clear:"清空所有",remove:"移除这个文件",choose:"选择你要上传的文件，并上传服务器",add:"增加上传文件",server:"上传服务器",abort:"终止上传",delete:"删除这个文件",status:"上传状态: ",idle:"挂载",failed:"上传失败"},400:"错误请求(400)",401:"未取得授权(401)",403:"拒绝访问(403)",404:"资源不存在(404)",405:"该功能被禁用(405)",408:"请求超时(408)",409:"数据冲突(409)",410:"数据已删除(410)",500:"服务器错误(500)",501:"服务未实现(501)",502:"网络错误(502)",503:"服务不可用(503)",504:"网络超时(504)",505:"HTTP版本不受支持(505)"},r={"en-US":a,"zh-CN":t},n=o({legacy:!1,locale:"en-US",globalInjection:!0,messages:r}),m=s(({app:e})=>{e.use(n)});export{m as default,n as i18n};
